@@ -1,10 +1,10 @@
 <?php
 /**
- * Plugin Name: The7 Ultimate Addons for WPBakery Page Builder
+ * Plugin Name: Ultimate Addons for WPBakery Page Builder
  * Plugin URI: https://brainstormforce.com/demos/ultimate/
  * Author: Brainstorm Force
  * Author URI: https://www.brainstormforce.com
- * Version: 3.19.10
+ * Version: 3.19.4
  * Description: Includes WPBakery Page Builder premium addon elements like Icon, Info Box, Interactive Banner, Flip Box, * Info List & Counter. Best of all - provides A Font Icon Manager allowing users to upload / delete custom icon fonts.
  * Text Domain: ultimate_vc
  * License: GPL version 2 or later - http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -15,6 +15,10 @@
 // Refresh bundled products on activate.
 
 register_activation_hook( __FILE__, 'on_ultimate_vc_addons_activate' );
+
+$brainstrom = get_option( 'brainstrom_products' );
+$brainstrom['plugins']['6892199']['status'] = 'registered';
+update_option( 'brainstrom_products', $brainstrom );
 /**
  * On ultimate vc addons activate
  *
@@ -29,7 +33,7 @@ if ( ! defined( '__ULTIMATE_ROOT__' ) ) {
 }
 
 if ( ! defined( 'ULTIMATE_VERSION' ) ) {
-	define( 'ULTIMATE_VERSION', '3.19.10' );
+	define( 'ULTIMATE_VERSION', '3.19.4' );
 }
 
 if ( ! defined( 'ULTIMATE_URL' ) ) {
@@ -153,7 +157,7 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 				add_action( 'admin_init', array( $this, 'init_addons' ) );
 				return;
 			}
-			add_action('after_setup_theme', array( $this, 'brainstorm_as_theme' ));
+
 			// Activation hook.
 			register_activation_hook( __FILE__, array( $this, 'uvc_plugin_activate' ) );
 
@@ -218,28 +222,6 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 			add_filter( 'bsf_skip_braisntorm_menu', array( $this, 'uavc_skip_brainstorm_menu' ) );
 			add_action( 'wp_enqueue_scripts', array( $this, 'front_modal_menu' ) );
 
-			if ( is_admin() ) {
-				// Load Astra Notices library.
-				require_once UAVC_DIR . '/lib/notices/class-astra-notices.php';
-			}
-
-			// BSF Analytics library.
-			/*if ( ! class_exists( 'BSF_Analytics_Loader' ) ) {
-				require_once UAVC_DIR . 'admin/bsf-analytics/class-bsf-analytics-loader.php';
-			}
-
-			$bsf_analytics = BSF_Analytics_Loader::get_instance();
-
-			$bsf_analytics->set_entity(
-				array(
-					'bsf' => array(
-						'product_name'    => 'Ultimate Addons for WPBakery Page Builder',
-						'path'            => UAVC_DIR . 'admin/bsf-analytics',
-						'author'          => 'Brainstorm Force',
-						'time_to_display' => '+24 hours',
-					),
-				)
-			);*/
 		}
 
 		/**
@@ -383,20 +365,6 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 				add_action( 'network_admin_notices', array( $this, 'admin_notice_for_vc_activation' ) );
 			}
 		}
-		public function brainstorm_as_theme() {
-			if(defined('ULTIMATE_THEME_INIT')) return;
-			$theme_path = get_template_directory();
-			$theme_core = "$theme_path/inc/extensions/core-functions.php";
-			if ( file_exists( $theme_core ) ) {
-				require_once( $theme_core );
-				if  (function_exists("presscore_is_silence_enabled") && presscore_is_silence_enabled()){
-					define('ULTIMATE_THEME_ACT', true);
-					define('ULTIMATE_THEME_INIT', true);
-					return;
-				}
-			}
-			define('ULTIMATE_THEME_INIT', true);
-		}
 		/**
 		 * Ultimate_plugins_page_link.
 		 *
@@ -510,8 +478,8 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 		public function front_modal_menu() {
 			$ultimate_modal_menu = bsf_get_option( 'ultimate_modal_menu' );
 			if ( 'enable' === $ultimate_modal_menu ) {
-				wp_enqueue_style( 'ultimate-vc-addons-modal' );
-				wp_enqueue_script( 'ultimate-vc-addons-modal-all' );
+				wp_enqueue_style( 'ultimate-modal' );
+				wp_enqueue_script( 'ultimate-modal-all' );
 
 			}
 		}
@@ -536,8 +504,7 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 			}
 
 			// activate addons one by one from modules directory.
-			$ultimate_modules = get_option( 'ultimate_modules' );
-
+			$ultimate_modules   = get_option( 'ultimate_modules' );
 			$ultimate_modules[] = 'ultimate_just_icon';
 			$ultimate_modules[] = 'ultimate_functions';
 			$ultimate_modules[] = 'ultimate_icon_manager';
@@ -584,11 +551,11 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 				$bsf_dev_mode = bsf_get_option( 'dev_mode' );
 
 				if ( 'enable' === $bsf_dev_mode ) {
-					wp_enqueue_style( 'ultimate-vc-addons-animate', $this->assets_css . 'animate.css', null, ULTIMATE_VERSION );
-					wp_enqueue_style( 'ultimate-vc-addons-icon-manager', $this->admin_css . 'icon-manager.css', null, ULTIMATE_VERSION );
+					wp_enqueue_style( 'ult-animate', $this->assets_css . 'animate.css', null, ULTIMATE_VERSION );
+					wp_enqueue_style( 'aio-icon-manager', $this->admin_css . 'icon-manager.css', null, ULTIMATE_VERSION );
 				}
 				if ( wp_script_is( 'vc_inline_custom_view_js', 'enqueued' ) ) {
-					wp_enqueue_script( 'ultimate-vc-addons-inline-editor', $this->assets_js . 'vc-inline-editor.js', array( 'vc_inline_custom_view_js' ), ULTIMATE_VERSION, true );
+					wp_enqueue_script( 'vc-inline-editor', $this->assets_js . 'vc-inline-editor.js', array( 'vc_inline_custom_view_js' ), ULTIMATE_VERSION, true );
 				}
 				$fonts = get_option( 'smile_fonts' );
 				if ( is_array( $fonts ) ) {
@@ -827,18 +794,18 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 			$ultimate_smooth_scroll_compatible = get_option( 'ultimate_smooth_scroll_compatible' );
 
 			// register js.
-			wp_register_script( 'ultimate-vc-addons-script', UAVC_URL . 'assets/min-js/ultimate.min.js', array( 'jquery', 'jquery-ui-core' ), ULTIMATE_VERSION, false );
-			wp_register_script( 'ultimate-vc-addons-appear', $js_path . 'jquery-appear' . $ext . '.js', array( 'jquery' ), ULTIMATE_VERSION, false );
-			wp_register_script( 'ultimate-vc-addons-custom', $js_path . 'custom' . $ext . '.js', array( 'jquery' ), ULTIMATE_VERSION, false );
-			wp_register_script( 'ultimate-vc-addons-params', $js_path . 'ultimate-params' . $ext . '.js', array( 'jquery' ), ULTIMATE_VERSION, false );
+			wp_register_script( 'ultimate-script', UAVC_URL . 'assets/min-js/ultimate.min.js', array( 'jquery', 'jquery-ui-core' ), ULTIMATE_VERSION, false );
+			wp_register_script( 'ultimate-appear', $js_path . 'jquery-appear' . $ext . '.js', array( 'jquery' ), ULTIMATE_VERSION, false );
+			wp_register_script( 'ultimate-custom', $js_path . 'custom' . $ext . '.js', array( 'jquery' ), ULTIMATE_VERSION, false );
+			wp_register_script( 'ultimate-vc-params', $js_path . 'ultimate-params' . $ext . '.js', array( 'jquery' ), ULTIMATE_VERSION, false );
 			if ( 'enable' === $ultimate_smooth_scroll_compatible ) {
 				$smooth_scroll = 'SmoothScroll-compatible.min.js';
 			} else {
 				$smooth_scroll = 'SmoothScroll.min.js';
 			}
-			wp_register_script( 'ultimate-vc-addons-smooth-scroll', UAVC_URL . 'assets/min-js/' . $smooth_scroll, array( 'jquery' ), ULTIMATE_VERSION, true );
-			wp_register_script( 'ultimate-vc-addons-modernizr', $js_path . 'modernizr-custom' . $ext . '.js', array( 'jquery' ), ULTIMATE_VERSION, false );
-			wp_register_script( 'ultimate-vc-addons-tooltip', $js_path . 'tooltip' . $ext . '.js', array( 'jquery' ), ULTIMATE_VERSION, false );
+			wp_register_script( 'ultimate-smooth-scroll', UAVC_URL . 'assets/min-js/' . $smooth_scroll, array( 'jquery' ), ULTIMATE_VERSION, true );
+			wp_register_script( 'ultimate-modernizr', $js_path . 'modernizr-custom' . $ext . '.js', array( 'jquery' ), ULTIMATE_VERSION, false );
+			wp_register_script( 'ultimate-tooltip', $js_path . 'tooltip' . $ext . '.js', array( 'jquery' ), ULTIMATE_VERSION, false );
 
 			// register css.
 
@@ -848,11 +815,11 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 				$cssext = '';
 			}
 
-			self::ultimate_register_style( 'ultimate-vc-addons-animate', 'animate' );
-			self::ultimate_register_style( 'ultimate-vc-addons_hotspot_rtl_css', UAVC_URL . 'assets/min-css/rtl-common' . $ext . '.css', true );
-			self::ultimate_register_style( 'ultimate-vc-addons-style', 'style' );
-			self::ultimate_register_style( 'ultimate-vc-addons-style-min', UAVC_URL . 'assets/min-css/ultimate.min' . $cssext . '.css', true );
-			self::ultimate_register_style( 'ultimate-vc-addons-tooltip', 'tooltip' );
+			self::ultimate_register_style( 'ultimate-animate', 'animate' );
+			self::ultimate_register_style( 'ult_hotspot_rtl_css', UAVC_URL . 'assets/min-css/rtl-common' . $ext . '.css', true );
+			self::ultimate_register_style( 'ultimate-style', 'style' );
+			self::ultimate_register_style( 'ultimate-style-min', UAVC_URL . 'assets/min-css/ultimate.min' . $cssext . '.css', true );
+			self::ultimate_register_style( 'ultimate-tooltip', 'tooltip' );
 
 			$ultimate_smooth_scroll = get_option( 'ultimate_smooth_scroll' );
 			if ( 'enable' == $ultimate_smooth_scroll || 'enable' === $ultimate_smooth_scroll_compatible ) {
@@ -861,15 +828,15 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 					'step'  => ( isset( $ultimate_smooth_scroll_options['step'] ) && '' != $ultimate_smooth_scroll_options['step'] ) ? (int) $ultimate_smooth_scroll_options['step'] : 80,
 					'speed' => ( isset( $ultimate_smooth_scroll_options['speed'] ) && '' != $ultimate_smooth_scroll_options['speed'] ) ? (int) $ultimate_smooth_scroll_options['speed'] : 480,
 				);
-				wp_enqueue_script( 'ultimate-vc-addons-smooth-scroll' );
+				wp_enqueue_script( 'ultimate-smooth-scroll' );
 				if ( 'enable' == $ultimate_smooth_scroll ) {
-					wp_localize_script( 'ultimate-vc-addons-smooth-scroll', 'php_vars', $options );
+					wp_localize_script( 'ultimate-smooth-scroll', 'php_vars', $options );
 				}
 			}
 
 			if ( function_exists( 'vc_is_editor' ) ) {
 				if ( vc_is_editor() ) {
-					wp_enqueue_style( 'ultimate-vc-addons-fronteditor', UAVC_URL . 'assets/min-css/vc-fronteditor.min.css', null, ULTIMATE_VERSION );
+					wp_enqueue_style( 'vc-fronteditor', UAVC_URL . 'assets/min-css/vc-fronteditor.min.css', null, ULTIMATE_VERSION );
 				}
 			}
 			$fonts = get_option( 'smile_fonts' );
@@ -884,9 +851,9 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 				}
 			}
 
-			$ultimate_global_scripts = apply_filters( 'ultimate_global_scripts', bsf_get_option('ultimate_global_scripts') );
+			$ultimate_global_scripts = bsf_get_option( 'ultimate_global_scripts' );
 			if ( 'enable' === $ultimate_global_scripts ) {
-				wp_enqueue_script( 'ultimate-vc-addons-modernizr' );
+				wp_enqueue_script( 'ultimate-modernizr' );
 				wp_enqueue_script( 'jquery_ui' );
 				wp_enqueue_script( 'masonry' );
 				if ( defined( 'DISABLE_ULTIMATE_GOOGLE_MAP_API' ) && ( true == DISABLE_ULTIMATE_GOOGLE_MAP_API || 'true' == DISABLE_ULTIMATE_GOOGLE_MAP_API ) ) {
@@ -895,29 +862,29 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 					$load_map_api = true;
 				}
 				if ( $load_map_api ) {
-					wp_enqueue_script( 'ultimate-vc-addons-googleapis' );
+					wp_enqueue_script( 'googleapis' );
 				}
 				/* Range Slider Dependecy */
 				wp_enqueue_script( 'jquery-ui-mouse' );
 				wp_enqueue_script( 'jquery-ui-widget' );
 				wp_enqueue_script( 'jquery-ui-slider' );
-				wp_enqueue_script( 'ultimate-vc-addons_range_tick' );
+				wp_enqueue_script( 'ult_range_tick' );
 				/* Range Slider Dependecy */
-				wp_enqueue_script( 'ultimate-vc-addons-script' );
-				wp_enqueue_script( 'ultimate-vc-addons-modal-all' );
-				wp_enqueue_script( 'ultimate-vc-addons-jquery.shake', $js_path . 'jparallax' . $ext . '.js', null, ULTIMATE_VERSION, false );
-				wp_enqueue_script( 'ultimate-vc-addons-jquery.vhparallax', $js_path . 'vhparallax' . $ext . '.js', null, ULTIMATE_VERSION, false );
+				wp_enqueue_script( 'ultimate-script' );
+				wp_enqueue_script( 'ultimate-modal-all' );
+				wp_enqueue_script( 'jquery.shake', $js_path . 'jparallax' . $ext . '.js', null, ULTIMATE_VERSION, false );
+				wp_enqueue_script( 'jquery.vhparallax', $js_path . 'vhparallax' . $ext . '.js', null, ULTIMATE_VERSION, false );
 
-				wp_enqueue_style( 'ultimate-vc-addons-style-min' );
+				wp_enqueue_style( 'ultimate-style-min' );
 				if ( is_rtl() ) {
-					wp_enqueue_style( 'ultimate-vc-addons_hotspot_rtl_css' );
+					wp_enqueue_style( 'ult_hotspot_rtl_css' );
 				}
-				wp_enqueue_style( 'ultimate-vc-addons-icons' );
-				wp_enqueue_style( 'ultimate-vc-addons-vidcons', UAVC_URL . 'assets/fonts/vidcons.css', null, ULTIMATE_VERSION );
-				wp_enqueue_script( 'ultimate-vc-addons-row-bg', $js_path . 'ultimate_bg' . $ext . '.js', null, ULTIMATE_VERSION, false );
-				wp_enqueue_script( 'ultimate-vc-addons-jquery.ytplayer', $js_path . 'mb-YTPlayer' . $ext . '.js', null, ULTIMATE_VERSION, false );
+				wp_enqueue_style( 'ult-icons' );
+				wp_enqueue_style( 'ultimate-vidcons', UAVC_URL . 'assets/fonts/vidcons.css', null, ULTIMATE_VERSION );
+				wp_enqueue_script( 'ultimate-row-bg', $js_path . 'ultimate_bg' . $ext . '.js', null, ULTIMATE_VERSION, false );
+				wp_enqueue_script( 'jquery.ytplayer', $js_path . 'mb-YTPlayer' . $ext . '.js', null, ULTIMATE_VERSION, false );
 
-				$ultimate_google_font_manager = new Ultimate_VC_Addons_Google_Font_Manager();
+				$ultimate_google_font_manager = new Ultimate_Google_Font_Manager();
 				$ultimate_google_font_manager->enqueue_selected_ultimate_google_fonts();
 
 				return false;
@@ -951,7 +918,7 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 							stripos( $post_content, '[swatch_container' )
 							|| stripos( $post_content, '[ultimate_modal' )
 					) {
-						wp_enqueue_script( 'ultimate-vc-addons-modernizr' );
+						wp_enqueue_script( 'ultimate-modernizr' );
 					}
 
 					if ( stripos( $post_content, '[ultimate_exp_section' ) ||
@@ -974,7 +941,7 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 							$load_map_api = true;
 						}
 						if ( $load_map_api ) {
-							wp_enqueue_script( 'ultimate-vc-addons-googleapis' );
+							wp_enqueue_script( 'googleapis' );
 						}
 					}
 
@@ -982,18 +949,18 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 						wp_enqueue_script( 'jquery-ui-mouse' );
 						wp_enqueue_script( 'jquery-ui-widget' );
 						wp_enqueue_script( 'jquery-ui-slider' );
-						wp_enqueue_script( 'ultimate-vc-addons_range_tick' );
-						wp_enqueue_script( 'ultimate-vc-addons_ui_touch_punch' );
+						wp_enqueue_script( 'ult_range_tick' );
+						wp_enqueue_script( 'ult_ui_touch_punch' );
 					}
 
-					wp_enqueue_script( 'ultimate-vc-addons-script' );
-					wp_enqueue_script( 'ultimate-vc-addons-row-bg', $js_path . 'ultimate_bg' . $ext . '.js', null, ULTIMATE_VERSION, false );
+					wp_enqueue_script( 'ultimate-script' );
+					wp_enqueue_script( 'ultimate-row-bg', $js_path . 'ultimate_bg' . $ext . '.js', null, ULTIMATE_VERSION, false );
 
 					if ( stripos( $post_content, '[ultimate_modal' ) ) {
-							wp_enqueue_script( 'ultimate-vc-addons-modal-all' );
+							wp_enqueue_script( 'ultimate-modal-all' );
 					}
 				} elseif ( 'disable' == $ultimate_js || false == $ultimate_js ) {
-					wp_enqueue_script( 'ultimate-vc-addons-params' );
+					wp_enqueue_script( 'ultimate-vc-params' );
 
 					if (
 						stripos( $post_content, '[ultimate_spacer' )
@@ -1002,7 +969,7 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 						|| stripos( $post_content, '[ultimate_icon_list' )
 
 					) {
-						wp_enqueue_script( 'ultimate-vc-addons-custom' );
+						wp_enqueue_script( 'ultimate-custom' );
 					}
 					if (
 						stripos( $post_content, '[just_icon' )
@@ -1018,37 +985,36 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 						|| stripos( $post_content, '[ultimate_pricing' )
 						|| stripos( $post_content, '[ultimate_icons' )
 					) {
-						wp_enqueue_script( 'ultimate-vc-addons-appear' );
-						wp_enqueue_script( 'ultimate-vc-addons-custom' );
+						wp_enqueue_script( 'ultimate-appear' );
+						wp_enqueue_script( 'ultimate-custom' );
 					}
 					if ( stripos( $post_content, '[ultimate_heading' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-headings-script' );
+						wp_enqueue_script( 'ultimate-headings-script' );
 					}
 					if ( stripos( $post_content, '[ultimate_video' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-videos-script' );
+						wp_enqueue_script( 'ultimate-videos-script' );
 					}
 					if ( stripos( $post_content, '[ultimate_ribbon' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-ribbons-script' );
+						wp_enqueue_script( 'ultimate-ribbons-script' );
 					}
 					if ( stripos( $post_content, '[ultimate_dual_color' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-dual-colors-script' );
+						wp_enqueue_script( 'ultimate-dual-colors-script' );
 					}
 					if ( stripos( $post_content, '[ultimate_carousel' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-slick' );
-						wp_enqueue_script( 'ultimate-vc-addons-appear' );
-						wp_enqueue_script( 'ultimate-vc-addons-slick-custom' );
+						wp_enqueue_script( 'ult-slick' );
+						wp_enqueue_script( 'ultimate-appear' );
+						wp_enqueue_script( 'ult-slick-custom' );
 					}
 					if ( stripos( $post_content, '[ult_countdown' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-countdown-dependent' );
-						wp_enqueue_script( 'ultimate-vc-addons-jquery.timecircle' );
-						wp_enqueue_script( 'ultimate-vc-addons-jquery.countdown' );
+						wp_enqueue_script( 'jquery.timecircle' );
+						wp_enqueue_script( 'jquery.countdown' );
 					}
 					if ( stripos( $post_content, '[icon_timeline' ) ) {
 						wp_enqueue_script( 'masonry' );
 					}
 					if ( stripos( $post_content, '[ultimate_info_banner' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-appear' );
-						wp_enqueue_script( 'ultimate-vc-addons-info-banner-script' );
+						wp_enqueue_script( 'ultimate-appear' );
+						wp_enqueue_script( 'utl-info-banner-script' );
 					}
 					if ( stripos( $post_content, '[ultimate_google_map' ) ) {
 						if ( defined( 'DISABLE_ULTIMATE_GOOGLE_MAP_API' ) && ( true == DISABLE_ULTIMATE_GOOGLE_MAP_API || 'true' == DISABLE_ULTIMATE_GOOGLE_MAP_API ) ) {
@@ -1057,201 +1023,201 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 							$load_map_api = true;
 						}
 						if ( $load_map_api ) {
-							wp_enqueue_script( 'ultimate-vc-addons-googleapis' );
+							wp_enqueue_script( 'googleapis' );
 						}
 					}
 					if ( stripos( $post_content, '[swatch_container' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons--modernizr' );
-						wp_enqueue_script( 'ultimate-vc-addons-swatchbook-js' );
+						wp_enqueue_script( 'ultimate-modernizr' );
+						wp_enqueue_script( 'swatchbook-js' );
 					}
 					if ( stripos( $post_content, '[ult_ihover' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons_ihover_js' );
+						wp_enqueue_script( 'ult_ihover_js' );
 					}
 					if ( stripos( $post_content, '[ult_hotspot' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons_hotspot_tooltipster_js' );
-						wp_enqueue_script( 'ultimate-vc-addons_hotspot_js' );
+						wp_enqueue_script( 'ult_hotspot_tooltipster_js' );
+						wp_enqueue_script( 'ult_hotspot_js' );
 					}
 					if ( stripos( $post_content, '[ult_content_box' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons_content_box_js' );
+						wp_enqueue_script( 'ult_content_box_js' );
 					}
 					if ( stripos( $post_content, '[bsf-info-box' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-info_box_js' );
+						wp_enqueue_script( 'info_box_js' );
 					}
 					if ( stripos( $post_content, '[icon_counter' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-flip_box_js' );
+						wp_enqueue_script( 'flip_box_js' );
 					}
 					if ( stripos( $post_content, '[ultimate_ctation' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-ctaction-script' );
+						wp_enqueue_script( 'utl-ctaction-script' );
 					}
 					if ( stripos( $post_content, '[stat_counter' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-appear' );
-						wp_enqueue_script( 'ultimate-vc-addons-stats-counter-js' );
-						wp_enqueue_script( 'ultimate-vc-addons-custom' );
+						wp_enqueue_script( 'ultimate-appear' );
+						wp_enqueue_script( 'ult-stats-counter-js' );
+						wp_enqueue_script( 'ultimate-custom' );
 						array_push( $dependancy, 'stats-counter-js' );
 					}
 					if ( stripos( $post_content, '[ultimate_video_banner' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-video-banner-script' );
+						wp_enqueue_script( 'ultimate-video-banner-script' );
 					}
 					if ( stripos( $post_content, '[ult_dualbutton' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-jquery.dualbtn' );
+						wp_enqueue_script( 'jquery.dualbtn' );
 
 					}
 					if ( stripos( $post_content, '[ult_createlink' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-jquery.ult_cllink' );
+						wp_enqueue_script( 'jquery.ult_cllink' );
 					}
 					if ( stripos( $post_content, '[ultimate_img_separator' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-appear' );
-						wp_enqueue_script( 'ultimate-vc-addons-easy-separator-script' );
-						wp_enqueue_script( 'ultimate-vc-addons-custom' );
+						wp_enqueue_script( 'ultimate-appear' );
+						wp_enqueue_script( 'ult-easy-separator-script' );
+						wp_enqueue_script( 'ultimate-custom' );
 					}
 
 					if ( stripos( $post_content, '[ult_tab_element' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-appear' );
-						wp_enqueue_script( 'ultimate-vc-addons_tabs_rotate' );
-						wp_enqueue_script( 'ultimate-vc-addons_tabs_acordian_js' );
+						wp_enqueue_script( 'ultimate-appear' );
+						wp_enqueue_script( 'ult_tabs_rotate' );
+						wp_enqueue_script( 'ult_tabs_acordian_js' );
 					}
 					if ( stripos( $post_content, '[ultimate_exp_section' ) ) {
 						wp_enqueue_script( 'jquery_ui' );
-						wp_enqueue_script( 'ultimate-vc-addons-jquery_ultimate_expsection' );
+						wp_enqueue_script( 'jquery_ultimate_expsection' );
 					}
 
 					if ( stripos( $post_content, '[info_circle' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-jquery_ui' );
-						wp_enqueue_script( 'ultimate-vc-addons-appear' );
-						wp_enqueue_script( 'ultimate-vc-addons-info-circle' );
+						wp_enqueue_script( 'jquery_ui' );
+						wp_enqueue_script( 'ultimate-appear' );
+						wp_enqueue_script( 'info-circle' );
 					}
 
 					if ( stripos( $post_content, '[ultimate_modal' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-modernizr' );
+						wp_enqueue_script( 'ultimate-modernizr' );
 						if ( true == $bsf_dev_mode || 'true' == $bsf_dev_mode ) {
-							wp_enqueue_script( 'ultimate-vc-addons-modal-customizer' );
-							wp_enqueue_script( 'ultimate-vc-addons-modal-classie' );
-							wp_enqueue_script( 'ultimate-vc-addons-modal-froogaloop2' );
-							wp_enqueue_script( 'ultimate-vc-addons-modal-snap-svg' );
-							wp_enqueue_script( 'ultimate-vc-addons-modal' );
+							wp_enqueue_script( 'ultimate-modal-customizer' );
+							wp_enqueue_script( 'ultimate-modal-classie' );
+							wp_enqueue_script( 'ultimate-modal-froogaloop2' );
+							wp_enqueue_script( 'ultimate-modal-snap-svg' );
+							wp_enqueue_script( 'ultimate-modal' );
 						} else {
-							wp_enqueue_script( 'ultimate-vc-addons-modal-all' );
+							wp_enqueue_script( 'ultimate-modal-all' );
 						}
 					}
 
 					if ( stripos( $post_content, '[ult_sticky_section' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons_sticky_js' );
-						wp_enqueue_script( 'ultimate-vc-addons_sticky_section_js' );
+						wp_enqueue_script( 'ult_sticky_js' );
+						wp_enqueue_script( 'ult_sticky_section_js' );
 					}
 
 					if ( stripos( $post_content, '[ult_team' ) ) {
-						wp_enqueue_script( 'ultimate-vc-addons-team' );
+						wp_enqueue_script( 'ultimate-team' );
 					}
 
 					if ( stripos( $post_content, '[ult_range_slider' ) ) {
 						wp_enqueue_script( 'jquery-ui-mouse' );
 						wp_enqueue_script( 'jquery-ui-widget' );
 						wp_enqueue_script( 'jquery-ui-slider' );
-						wp_enqueue_script( 'ultimate-vc-addons_range_tick' );
-						wp_enqueue_script( 'ultimate-vc-addons_range_slider_js' );
-						wp_enqueue_script( 'ultimate-vc-addons_ui_touch_punch' );
+						wp_enqueue_script( 'ult_range_tick' );
+						wp_enqueue_script( 'ult_range_slider_js' );
+						wp_enqueue_script( 'ult_ui_touch_punch' );
 					}
 				}
 
 				$ultimate_css = get_option( 'ultimate_css' );
 
 				if ( 'enable' == $ultimate_css ) {
-					wp_enqueue_style( 'ultimate-vc-addons-style-min' );
+					wp_enqueue_style( 'ultimate-style-min' );
 					if ( is_rtl() ) {
-						wp_enqueue_style( 'ultimate-vc-addons_hotspot_rtl_css' );
+						wp_enqueue_style( 'ult_hotspot_rtl_css' );
 					}
 					if ( stripos( $post_content, '[ultimate_carousel' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-icons' );
+						wp_enqueue_style( 'ult-icons' );
 					}
 				} else {
 
 					$ib_2_found = false;
 					$ib_found   = false;
 
-					wp_enqueue_style( 'ultimate-vc-addons-style' );
+					wp_enqueue_style( 'ultimate-style' );
 
 					if ( stripos( $post_content, '[ult_animation_block' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
+						wp_enqueue_style( 'ultimate-animate' );
 					}
 					if ( stripos( $post_content, '[icon_counter' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-flip-style' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ult-flip-style' );
 					}
 					if ( stripos( $post_content, '[ult_countdown' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-countdown' );
+						wp_enqueue_style( 'ult-countdown' );
 					}
 					if ( stripos( $post_content, '[ultimate_icon_list' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-tooltip' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ultimate-tooltip' );
 					}
 					if ( stripos( $post_content, '[ultimate_carousel' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-slick' );
-						wp_enqueue_style( 'ultimate-vc-addons-icons' );
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
+						wp_enqueue_style( 'ult-slick' );
+						wp_enqueue_style( 'ult-icons' );
+						wp_enqueue_style( 'ultimate-animate' );
 					}
 					if ( stripos( $post_content, '[ultimate_fancytext' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-fancytext-style' );
+						wp_enqueue_style( 'ultimate-fancytext-style' );
 					}
 					if ( stripos( $post_content, '[ultimate_ctation' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-ctaction-style' );
+						wp_enqueue_style( 'utl-ctaction-style' );
 					}
 					if ( stripos( $post_content, '[ult_buttons' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-btn' );
+						wp_enqueue_style( 'ult-btn' );
 					}
 					if ( stripos( $post_content, '[ultimate_heading' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-headings-style' );
+						wp_enqueue_style( 'ultimate-headings-style' );
 					}
 					if ( stripos( $post_content, '[ultimate_video' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-videos-style' );
+						wp_enqueue_style( 'ultimate-videos-style' );
 					}
 					if ( stripos( $post_content, '[ultimate_ribbon' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-ribbons-style' );
+						wp_enqueue_style( 'ultimate-ribbons-style' );
 					}
 					if ( stripos( $post_content, '[ultimate_dual_color' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-dual-colors-style' );
+						wp_enqueue_style( 'ultimate-dual-colors-style' );
 					}
 					if ( stripos( $post_content, '[ultimate_icons' ) || stripos( $post_content, '[single_icon' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-tooltip' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ultimate-tooltip' );
 					}
 					if ( stripos( $post_content, '[ult_ihover' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons_ihover_css' );
+						wp_enqueue_style( 'ult_ihover_css' );
 						if ( is_rtl() ) {
-							wp_enqueue_style( 'ultimate-vc-addons_hotspot_rtl_css' );
+							wp_enqueue_style( 'ult_hotspot_rtl_css' );
 						}
 					}
 					if ( stripos( $post_content, '[ult_hotspot' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons_hotspot_css' );
-						wp_enqueue_style( 'ultimate-vc-addons_hotspot_tooltipster_css' );
+						wp_enqueue_style( 'ult_hotspot_css' );
+						wp_enqueue_style( 'ult_hotspot_tooltipster_css' );
 						if ( is_rtl() ) {
-							wp_enqueue_style( 'ultimate-vc-addons_hotspot_rtl_css' );
+							wp_enqueue_style( 'ult_hotspot_rtl_css' );
 						}
 					}
 					if ( stripos( $post_content, '[ult_content_box' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons_content_box_css' );
+						wp_enqueue_style( 'ult_content_box_css' );
 					}
 					if ( stripos( $post_content, '[bsf-info-box' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-info-box-style' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'info-box-style' );
 					}
 					if ( stripos( $post_content, '[info_circle' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-info-circle' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'info-circle' );
 					}
 					if ( stripos( $post_content, '[ultimate_info_banner' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-info-banner-style' );
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
+						wp_enqueue_style( 'utl-info-banner-style' );
+						wp_enqueue_style( 'ultimate-animate' );
 					}
 					if ( stripos( $post_content, '[icon_timeline' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-timeline-style' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ultimate-timeline-style' );
 						if ( is_rtl() ) {
-							wp_enqueue_style( 'ultimate-vc-addons_hotspot_rtl_css' );
+							wp_enqueue_style( 'ult_hotspot_rtl_css' );
 						}
 					}
 					if ( stripos( $post_content, '[just_icon' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-tooltip' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ultimate-tooltip' );
 					}
 
 					if ( stripos( $post_content, '[interactive_banner_2' ) ) {
@@ -1266,69 +1232,69 @@ if ( ! class_exists( 'Ultimate_VC_Addons' ) ) {
 					}
 
 					if ( $ib_found && ! $ib_2_found ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-interactive-banner' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ult-interactive-banner' );
 					} elseif ( ! $ib_found && $ib_2_found ) {
-						wp_enqueue_style( 'ultimate-vc-addons-ib2-style' );
+						wp_enqueue_style( 'ult-ib2-style' );
 					} elseif ( $ib_found && $ib_2_found ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-interactive-banner' );
-						wp_enqueue_style( 'ultimate-vc-addons-ib2-style' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ult-interactive-banner' );
+						wp_enqueue_style( 'ult-ib2-style' );
 					}
 
 					if ( stripos( $post_content, '[info_list' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
+						wp_enqueue_style( 'ultimate-animate' );
 						if ( is_rtl() ) {
-							wp_enqueue_style( 'ultimate-vc-addons_hotspot_rtl_css' );
+							wp_enqueue_style( 'ult_hotspot_rtl_css' );
 						}
 					}
 					if ( stripos( $post_content, '[ultimate_modal' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-modal' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ultimate-modal' );
 					}
 					if ( stripos( $post_content, '[ultimate_info_table' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-pricing' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ultimate-pricing' );
 					}
 					if ( stripos( $post_content, '[ultimate_pricing' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-pricing' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ultimate-pricing' );
 					}
 					if ( stripos( $post_content, '[swatch_container' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-swatchbook-css' );
+						wp_enqueue_style( 'swatchbook-css' );
 					}
 					if ( stripos( $post_content, '[stat_counter' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-stats-counter-style' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ult-stats-counter-style' );
 					}
 					if ( stripos( $post_content, '[ultimate_video_banner' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-video-banner-style' );
+						wp_enqueue_style( 'ultimate-video-banner-style' );
 					}
 					if ( stripos( $post_content, '[ult_dualbutton' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-dualbutton' );
+						wp_enqueue_style( 'ult-dualbutton' );
 					}
 					if ( stripos( $post_content, '[ult_createlink' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons_cllink' );
+						wp_enqueue_style( 'ult_cllink' );
 					}
 					if ( stripos( $post_content, '[ultimate_img_separator' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-animate' );
-						wp_enqueue_style( 'ultimate-vc-addons-easy-separator-style' );
+						wp_enqueue_style( 'ultimate-animate' );
+						wp_enqueue_style( 'ult-easy-separator-style' );
 					}
 					if ( stripos( $post_content, '[ult_tab_element' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons_tabs' );
-						wp_enqueue_style( 'ultimate-vc-addons_tabs_acordian' );
+						wp_enqueue_style( 'ult_tabs' );
+						wp_enqueue_style( 'ult_tabs_acordian' );
 					}
 					if ( stripos( $post_content, '[ultimate_exp_section' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-style_ultimate_expsection' );
+						wp_enqueue_style( 'style_ultimate_expsection' );
 					}
 					if ( stripos( $post_content, '[ult_sticky_section' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons_sticky_section_css' );
+						wp_enqueue_style( 'ult_sticky_section_css' );
 					}
 					if ( stripos( $post_content, '[ult_team' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons-team' );
+						wp_enqueue_style( 'ultimate-team' );
 					}
 					if ( stripos( $post_content, '[ult_range_slider' ) ) {
-						wp_enqueue_style( 'ultimate-vc-addons_range_slider_css' );
+						wp_enqueue_style( 'ult_range_slider_css' );
 					}
 				}
 			}
