@@ -137,10 +137,6 @@ if ( ! class_exists( 'Ultimate_Admin_Area' ) ) {
 			add_action( 'wp_ajax_update_ultimate_debug_options', array( $this, 'update_debug_settings' ) );
 			add_action( 'wp_ajax_update_ultimate_modules', array( $this, 'update_modules' ) );
 			add_action( 'wp_ajax_update_css_options', array( $this, 'update_css_options' ) );
-
-			if ( ! current_user_can( 'manage_options' ) ) {
-				return false;
-			}
 			add_action( 'wp_ajax_update_dev_notes', array( $this, 'update_dev_notes' ) );
 			add_filter( 'update_footer', array( $this, 'debug_link' ), 999 );
 		}
@@ -262,29 +258,26 @@ if ( ! class_exists( 'Ultimate_Admin_Area' ) ) {
 				}
 
 				$bsf_dev_mode = bsf_get_option( 'dev_mode' );
-				wp_enqueue_script( 'jquery-migrate' );
-				wp_register_style( 'ultimate-vc-addons-admin-style', UAVC_URL . 'admin/css/style.css', null, ULTIMATE_VERSION );
 
-				wp_register_style( 'ultimate-vc-addons-chosen-style', UAVC_URL . 'admin/vc_extend/css/chosen.css', null, ULTIMATE_VERSION );
-				wp_register_script( 'ultimate-vc-addons-chosen-script', UAVC_URL . 'admin/vc_extend/js/chosen.js', null, ULTIMATE_VERSION, true );
+				wp_register_style( 'ultimate-admin-style', UAVC_URL . 'admin/css/style.css', null, ULTIMATE_VERSION );
 
-				wp_register_script( 'ultimate-vc-addons-backend-script', UAVC_URL . 'admin/js/ultimate-vc-backend.min.js', array( 'jquery' ), ULTIMATE_VERSION, true );
-				wp_register_style( 'ultimate-vc-addons-backend-style', UAVC_URL . 'admin/css/ultimate-vc-backend' . $css_ext, null, ULTIMATE_VERSION );
+				wp_register_style( 'ultimate-chosen-style', UAVC_URL . 'admin/vc_extend/css/chosen.css', null, ULTIMATE_VERSION );
+				wp_register_script( 'ultimate-chosen-script', UAVC_URL . 'admin/vc_extend/js/chosen.js', null, ULTIMATE_VERSION, true );
+
+				wp_register_script( 'ultimate-vc-backend-script', UAVC_URL . 'admin/js/ultimate-vc-backend.min.js', array( 'jquery' ), ULTIMATE_VERSION, true );
+				wp_register_style( 'ultimate-vc-backend-style', UAVC_URL . 'admin/css/ultimate-vc-backend' . $css_ext, null, ULTIMATE_VERSION );
 
 				if ( 'enable' === $bsf_dev_mode ) {
-					wp_enqueue_style( 'ultimate-vc-addons-admin-style' );
+					wp_enqueue_style( 'ultimate-admin-style' );
 				} else {
 					wp_enqueue_style( 'wp-color-picker' );
-					wp_enqueue_script( 'ultimate-vc-addons-backend-script' );
-					wp_enqueue_style( 'ultimate-vc-addons-backend-style' );
+					wp_enqueue_script( 'ultimate-vc-backend-script' );
+					wp_enqueue_style( 'ultimate-vc-backend-style' );
 				}
 			}
 
-			wp_register_script( 'ultimate-vc-addons-admin-media', UAVC_URL . 'admin/js/admin-media.js', array( 'jquery' ), ULTIMATE_VERSION, false );
-			wp_enqueue_script( 'ultimate-vc-addons-admin-media' );
-
 			wp_localize_script(
-				'ultimate-vc-addons-admin-media',
+				'jquery',
 				'uavc',
 				array(
 					'add_zipped_font'        => wp_create_nonce( 'smile-add-zipped-fonts-nonce' ),
@@ -330,8 +323,8 @@ if ( ! class_exists( 'Ultimate_Admin_Area' ) ) {
 			}
 
 			$page = add_menu_page(
-				'The7 Ultimate',
-				'The7 Ultimate',
+				'Ultimate',
+				'Ultimate',
 				$role,
 				'about-ultimate',
 				array( $this, 'load_about' ),
@@ -429,10 +422,10 @@ if ( ! class_exists( 'Ultimate_Admin_Area' ) ) {
 				array( $this, 'ultimate_icon_manager_menu' )
 			);
 
-			$AIO_Icon_Manager = new Ultimate_VC_Addons_Icon_Manager();// phpcs:ignore WordPress.NamingConventions.ValidVariableName.VariableNotSnakeCase
+			$AIO_Icon_Manager = new AIO_Icon_Manager();// phpcs:ignore WordPress.NamingConventions.ValidVariableName.VariableNotSnakeCase
 			add_action( 'admin_print_scripts-' . $icon_manager_page, array( $AIO_Icon_Manager, 'admin_scripts' ) ); // phpcs:ignore WordPress.NamingConventions.ValidVariableName.VariableNotSnakeCase
 
-			$Ultimate_Google_Font_Manager = new Ultimate_VC_Addons_Google_Font_Manager(); // phpcs:ignore WordPress.NamingConventions.ValidVariableName.VariableNotSnakeCase
+			$Ultimate_Google_Font_Manager = new Ultimate_Google_Font_Manager(); // phpcs:ignore WordPress.NamingConventions.ValidVariableName.VariableNotSnakeCase
 			$google_font_manager_page     = add_submenu_page(
 				'about-ultimate',
 				__( 'Google Font Manager', 'ultimate_vc' ),
@@ -476,7 +469,7 @@ if ( ! class_exists( 'Ultimate_Admin_Area' ) ) {
 		 * @access public
 		 */
 		public function ultimate_icon_manager_menu() {
-			$AIO_Icon_Manager = new Ultimate_VC_Addons_Icon_Manager();// phpcs:ignore WordPress.NamingConventions.ValidVariableName.VariableNotSnakeCase
+			$AIO_Icon_Manager = new AIO_Icon_Manager();// phpcs:ignore WordPress.NamingConventions.ValidVariableName.VariableNotSnakeCase
 			$AIO_Icon_Manager->icon_manager_dashboard();// phpcs:ignore WordPress.NamingConventions.ValidVariableName.VariableNotSnakeCase
 		}
 		/**
@@ -569,10 +562,6 @@ if ( ! class_exists( 'Ultimate_Admin_Area' ) ) {
 		 */
 		public function update_modules() {
 
-			if ( ! current_user_can( 'manage_options' ) ) {
-				return false;
-			}
-
 			check_ajax_referer( 'ultimate-modules-setting', 'security' );
 
 			if ( isset( $_POST['ultimate_row'] ) ) {
@@ -627,10 +616,6 @@ if ( ! class_exists( 'Ultimate_Admin_Area' ) ) {
 		 */
 		public function update_debug_settings() {
 
-			if ( ! current_user_can( 'manage_options' ) ) {
-				return false;
-			}
-
 			check_ajax_referer( 'ultimate-debug-settings', 'security' );
 
 			if ( isset( $_POST['ultimate_video_fixer'] ) ) {
@@ -740,10 +725,6 @@ if ( ! class_exists( 'Ultimate_Admin_Area' ) ) {
 		 */
 		public function update_settings() {
 
-			if ( ! current_user_can( 'manage_options' ) ) {
-				return false;
-			}
-
 			check_ajax_referer( 'smooth-scroll-setting', 'security' );
 
 			if ( isset( $_POST['ultimate_smooth_scroll'] ) ) {
@@ -776,10 +757,6 @@ if ( ! class_exists( 'Ultimate_Admin_Area' ) ) {
 		 */
 		public function update_css_options() {
 
-			if ( ! current_user_can( 'manage_options' ) ) {
-				return false;
-			}
-
 			check_ajax_referer( 'css-settings-setting', 'security' );
 
 			if ( isset( $_POST['ultimate_css'] ) ) {
